==> org.eclipse.tracecompass.tmf.core.source_5.1.0.201909110900.jar: org/eclipse/tracecompass/tmf/core/filter/xml/TmfFilterXMLParser.java <==
/*******************************************************************************
 * Copyright (c) 2010, 2014 Ericsson
 *
 * All rights reserved. This program and the accompanying materials are
 * made available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Yuriy Vashchuk (yvashchuk@gmail.com) - Initial API and implementation
 *******************************************************************************/

package org.eclipse.tracecompass.tmf.core.filter.xml;

import java.io.IOException;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParserFactory;

import org.eclipse.tracecompass.internal.tmf.core.Activator;
import org.eclipse.tracecompass.tmf.core.filter.model.ITmfFilterTreeNode;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;

/**
 * The SAX based XML parser
 *
 * @version 1.0
 * @author Yuriy Vashchuk
 * @author Patrick Tasse
 */
public class TmfFilterXMLParser {

    private static ITmfFilterTreeNode fRoot = null;

    /**
     * The XMLParser constructor
     *
     * @param uri The XML file to parse
     * @throws SAXException  SAX exception
     * @throws IOException  IO exception
     */
    public TmfFilterXMLParser(final String uri) throws SAXException, IOException {

        SAXParserFactory m_parserFactory = SAXParserFactory.newInstance();
        XMLReader saxReader = null;
        try {
            m_parserFactory.setFeature("http://xml.org/sax/features/external-general-entities", false); //$NON-NLS-1$
            m_parserFactory.setFeature("http://xml.org/sax/features/external-parameter-entities", false); //$NON-NLS-1$
            m_parserFactory.setFeature("http://apache.org/xml/features/nonvalidating/load-external-dtd", false); //$NON-NLS-1$
            m_parserFactory.setNamespaceAware(true);

            saxReader = m_parserFactory.newSAXParser().getXMLReader();
            saxReader.setContentHandler(new TmfFilterContentHandler());
            saxReader.parse(uri);

            fRoot = ((TmfFilterContentHandler) saxReader.getContentHandler()).getTree();

        } catch (ParserConfigurationException e) {
            Activator.logError("Error to parse the configuration ", e);  //$NON-NLS-1$
        }
    }

    /**
     * Getter of tree
     *
     * @return The builded tree
     */
    public ITmfFilterTreeNode getTree() {
        return fRoot;
    }
}

==> org.eclipse.tracecompass.tmf.core.source_5.2.0.201912171220.jar: org/eclipse/tracecompass/tmf/core/filter/xml/TmfFilterXMLParser.java <==
/*******************************************************************************
 * Copyright (c) 2010, 2014 Ericsson
 *
 * All rights reserved. This program and the accompanying materials are
 * made available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Yuriy Vashchuk (yvashchuk@gmail.com) - Initial API and implementation
 *******************************************************************************/

package org.eclipse.tracecompass.tmf.core.filter.xml;

import java.io.IOException;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParserFactory;

import org.eclipse.tracecompass.common.core.xml.XmlUtils;
import org.eclipse.tracecompass.internal.tmf.core.Activator;
import org.eclipse.tracecompass.tmf.core.filter.model.ITmfFilterTreeNode;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;

/**
 * The SAX based XML parser
 *
 * @version 1.0
 * @author Yuriy Vashchuk
 * @author Patrick Tasse
 */
public class TmfFilterXMLParser {

    private static ITmfFilterTreeNode fRoot = null;

    /**
     * The XMLParser constructor
     *
     * @param uri The XML file to parse
     * @throws SAXException  SAX exception
     * @throws IOException  IO exception
     */
    public TmfFilterXMLParser(final String uri) throws SAXException, IOException {

        XMLReader saxReader = null;
        try {
            SAXParserFactory m_parserFactory = XmlUtils.newSafeSaxParserFactory();


            saxReader = m_parserFactory.newSAXParser().getXMLReader();
            saxReader.setContentHandler(new TmfFilterContentHandler());
            saxReader.parse(uri);

            fRoot = ((TmfFilterContentHandler) saxReader.getContentHandler()).getTree();

        } catch (ParserConfigurationException e) {
            Activator.logError("Error to parse the configuration ", e);  //$NON-NLS-1$
        }
    }

    /**
     * Getter of tree
     *
     * @return The builded tree
     */
    public ITmfFilterTreeNode getTree() {
        return fRoot;
    }
}
